/* wptRegistry.h - Registry interface
 *	Copyright (C) 2000-2007 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2 
 * of the License, or (at your option) any later version.
 *  
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 */
#ifndef WPT_REGISTRY_H
#define WPT_REGISTRY_H


/* Symbolic configuration IDs */
enum cfg_t {
    CFG_INVALID=0,
    CFG_CACHETIME,
    CFG_WORDWRAP,
    CFG_FILEEXT,
    CFG_VIEWER,
    CFG_ALWAYSTRUST,
    CFG_AUTOBACKUP,
    CFG_AUTOBAKMODE,
    CFG_DISHOTKEYS,
    CFG_NOZIP_MMEDIA,
    CFG_EXPERT,
    CFG_FM_PROGRESS,
    CFG_BACKUP_INC_SKR,
    /* end of id list */
    CFG_AUTOBAKPATH,
    CFG_KSERV_CONF,    
};

extern const char *cfg[];

struct winpt_prefs_s {
    int no_hotkeys;	/* disable ALL hotkeys */
    int word_wrap;	/* set word wrapping (0 means to disable it) */
    int cache_time;	/* caching time for passphrase */
    int use_viewer;	/* use clipboard viewer for displaying plaintext */
    int no_zip_mmedia;  /* disable compression for multi-media files (movies, music) */
    int always_trust;	/* skip key validation (1 means yes) */
    int auto_backup;	/* automatic backup (1 means activated) */
    int default_ext;	/* 1 = GPG, PGP otherwise. */
    int no_safe_pwd_ctrl; /* disable the additional 'safe' window hooks. */
    struct {
	int include_secr;/* including secret keyrings. */
	int mode;	/* backup mode */
	char *path;	/* keyring backup path */
    } backup;
    char *kserv_conf;	/* path to the keyserver config file. */
    int expert;		/* run in expert mode. */
    struct {
	int progress;	/* show the progress bar dialog. */
    } fm;
    char *homedir;     /* mobile home directory. */

    /* Actual no registry options but virtual options. */
    struct {
	unsigned int ask_cert_level:1;
	unsigned int ask_cert_expire:1;
    } gpg;
};
typedef struct winpt_prefs_s *winpt_prefs_t;
extern winpt_prefs_s reg_prefs;

/*-- wptRegistry.cpp --*/
void free_reg_prefs (void);
int regist_inst_gnupg (int create_mokey);
int regist_inst_winpt (int with_ext, int *created);
int set_reg_winpt_single (int id, int val);
int get_reg_winpt_single (int id);
int set_reg_winpt_prefs (winpt_prefs_t opt);
int get_reg_winpt_prefs (winpt_prefs_t opt);
char* get_reg_entry (HKEY root_key, const char *dir, const char *key);
int set_reg_entry (HKEY root_key, const char * dir, const char * key,
				   const char *value);
int set_reg_key (HKEY root_key, const char * dir, const char * key,
				 const char * value);
int set_reg_entry_gpg (const char *key, const char *value);
char* get_reg_entry_gpg (const char * key);
char* get_reg_entry_mo (void);
int set_reg_entry_keyserver (const char * name, const char *val);
char* get_reg_entry_keyserver( const char * name );
int set_reg_winpt_flag (const char *name, int val);
int get_reg_winpt_flag (const char *name);
char* get_reg_entry_gpg4win (const char *path);
int is_gpg4win_installed (void);

#endif /* WPT_REGISTRY_H */
