/* wptSymEnc.cpp - Symmetric encryption support
 *	Copyright (C) 2002-2006 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2 
 * of the License, or (at your option) any later version.
 *  
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <windows.h>

#include "wptGPG.h"
#include "wptCommonCtl.h"
#include "wptContext.h"
#include "wptDlgs.h"
#include "wptNLS.h"
#include "wptUTF8.h"
#include "wptTypes.h"
#include "wptErrors.h"


/* Simple passphrase callback. The hook pointer is the passphrase itself.
   Return value: 0 on success. */
gpgme_error_t
sym_passphrase_cb (void *hook, const char *hint, const char *pass_inf,
		   int prev_was_bad, int fd)
{
    const char *pass = (const char*)hook;
    HANDLE hd = (HANDLE)fd;
    DWORD n;

    if (!pass)
	return gpg_error (GPG_ERR_INV_ARG);

    if (!WriteFile (hd, pass, strlen (pass), &n, NULL))
	log_debug ("sym_passphrase_cb: WriteFile() failed ec=%d\n", w32_errno);
    if (!WriteFile (hd, "\n", 1, &n, NULL))
	log_debug ("sym_passphrase_cb: WriteFile() failed ec=%d\n", w32_errno);
    
    return 0;
}


/* Perform symmetric encryption on the current clipboard data.
   Return 0 for success. */
gpgme_error_t
gpg_clip_sym_encrypt (void)
{
    gpgme_ctx_t ctx;
    gpgme_data_t plain=NULL;
    gpgme_data_t ciph=NULL;
    gpgme_error_t rc;
    char *pass = NULL;
    int cancel = 0;
    
    pass = request_passphrase2 (_("Symmetric Encryption"), 
				PASSDLG_NOTEMPTY, &cancel);
    if (cancel)
	return 0;
    rc = gpgme_new (&ctx);
    if (rc)
	goto leave;
    rc = gpg_data_utf8_new_from_clipboard (&plain, 0, NULL);
    if (rc)
	goto leave;
    rc = gpgme_data_new (&ciph);
    if (rc)
	goto leave;
    gpgme_set_armor (ctx, 1);
    gpgme_set_textmode (ctx, 1);

    gpgme_set_passphrase_cb (ctx, sym_passphrase_cb, pass);

    rc = gpgme_op_encrypt (ctx, NULL, (gpgme_encrypt_flags_t)0, plain, ciph);
    if (rc)
	msg_box (NULL, gpgme_strerror (rc), _("Symmetric Encryption"), MB_ERR);
    else {
	show_msg (GetDesktopWindow (), 1500, _("GnuPG Status: Finished"));
	gpg_data_release_to_clipboard (ciph, 1);
	ciph = NULL;
    }

leave:
    if (plain)
	gpgme_data_release (plain);
    if (ciph)
	gpgme_data_release (ciph);
    gpgme_release (ctx);
    sfree_if_alloc (pass);
    return rc;
}
